package com.jjt.calc.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.calc.domain.TwinCalcAlarms;

/**
 * 告警数据统计Mapper接口
 * 
 * @author wukai
 * @date 2025-01-18
 */
public interface TwinCalcAlarmsMapper extends BaseMapper<TwinCalcAlarms>
{
    /**
     * 查询告警数据统计
     * 
     * @param id 告警数据统计主键
     * @return 告警数据统计
     */
    public TwinCalcAlarms selectTwinCalcAlarmsById(Long id);

    /**
     * 查询告警数据统计列表
     * 
     * @param twinCalcAlarms 告警数据统计
     * @return 告警数据统计集合
     */
    public List<TwinCalcAlarms> selectTwinCalcAlarmsList(TwinCalcAlarms twinCalcAlarms);

    /**
     * 新增告警数据统计
     * 
     * @param twinCalcAlarms 告警数据统计
     * @return 结果
     */
    public int insertTwinCalcAlarms(TwinCalcAlarms twinCalcAlarms);

    /**
     * 修改告警数据统计
     * 
     * @param twinCalcAlarms 告警数据统计
     * @return 结果
     */
    public int updateTwinCalcAlarms(TwinCalcAlarms twinCalcAlarms);

    /**
     * 删除告警数据统计
     * 
     * @param id 告警数据统计主键
     * @return 结果
     */
    public int deleteTwinCalcAlarmsById(Long id);

    /**
     * 批量删除告警数据统计
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinCalcAlarmsByIds(Long[] ids);
}
